@@ -11,8 +11,10 @@ use crate::models::inputs::HasInputs;
 
 pub(crate) mod action;
 pub(crate) mod coordinate;
+pub(crate) mod dependabot;
 pub(crate) mod inputs;
 pub(crate) mod uses;
+pub(crate) mod version;
 pub(crate) mod workflow;
 
 pub(crate) trait AsDocument<'a, 'doc> {
