@@ -867,6 +867,17 @@ fn ref_version_mismatch() -> Result<()> {
             .run()?
     );
 
+    // Tags that point to other tags are handled correctly.
+    insta::assert_snapshot!(
+        zizmor()
+            .offline(false)
+            .input(input_under_test(
+                "ref-version-mismatch/nested-annotated-tags.yml"
+            ))
+            .run()?,
+        @"No findings to report. Good job! (1 suppressed)"
+    );
+
     Ok(())
 }
 
@@ -968,8 +979,9 @@ fn dependabot_execution() -> Result<()> {
        |     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ enabled here
        |
        = note: audit confidence → High
+       = note: this finding has an auto-fix
 
-    1 finding: 0 informational, 0 low, 0 medium, 1 high
+    1 findings (1 fixable): 0 informational, 0 low, 0 medium, 1 high
     "
     );
 
@@ -992,8 +1004,9 @@ fn dependabot_cooldown() -> Result<()> {
       |     ^^^^^^^^^^^^^^^^^^^^^^ missing cooldown configuration
       |
       = note: audit confidence → High
+      = note: this finding has an auto-fix
 
-    1 finding: 0 informational, 0 low, 1 medium, 0 high
+    1 findings (1 fixable): 0 informational, 0 low, 1 medium, 0 high
     "
     );
 
@@ -1011,8 +1024,9 @@ fn dependabot_cooldown() -> Result<()> {
       |     ^^^^^^^^^^^^ no default-days configured
       |
       = note: audit confidence → High
+      = note: this finding has an auto-fix
 
-    1 finding: 0 informational, 0 low, 1 medium, 0 high
+    1 findings (1 fixable): 0 informational, 0 low, 1 medium, 0 high
     ");
 
     insta::assert_snapshot!(
@@ -1029,9 +1043,71 @@ fn dependabot_cooldown() -> Result<()> {
       |       ^^^^^^^^^^^^^^^ insufficient default-days configured
       |
       = note: audit confidence → Medium
+      = note: this finding has an auto-fix
 
-    1 finding: 0 informational, 1 low, 0 medium, 0 high
+    1 findings (1 fixable): 0 informational, 1 low, 0 medium, 0 high
     ");
 
     Ok(())
 }
+
+#[test]
+fn concurrency_limits() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "concurrency-limits/missing.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?,
+        @r"
+    help[concurrency-limits]: insufficient job-level concurrency limits
+      --> @@INPUT@@:1:1
+       |
+     1 | / name: Workflow without concurrency
+     2 | | on: push
+     3 | | permissions: {}
+    ...  |
+    10 | |     - name: 1-ok
+    11 | |       run: echo ok
+       | |___________________^ missing concurrency setting
+       |
+       = note: audit confidence → High
+
+    1 finding: 0 informational, 1 low, 0 medium, 0 high
+    "
+    );
+
+    // Note: per #1302, we intentionally don't produce findings here.
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "concurrency-limits/cancel-false.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?,
+        @"No findings to report. Good job!"
+    );
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "concurrency-limits/no-cancel.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?,
+        @r"
+    help[concurrency-limits]: insufficient job-level concurrency limits
+     --> @@INPUT@@:5:1
+      |
+    5 | concurrency: group
+      | ^^^^^^^^^^^^^^^^^^ concurrency is missing cancel-in-progress
+      |
+      = note: audit confidence → High
+
+    1 finding: 0 informational, 1 low, 0 medium, 0 high
+    "
+    );
+
+    Ok(())
+}
